unicode = open('unicode.txt', 'r', encoding="UTF-8").read().split(' ')
legacy = open('legacy.txt', 'r', encoding="UTF-8").read().split(' ')
legacy_isi = open('isi font legacy.txt', 'r', encoding="UTF-8").read().split(' ')


def uni2fm(user_input=None):
    replaced = user_input
    for i in range(len(unicode)):
        if unicode[i] in user_input:
            replaced = replaced.replace(unicode[i], legacy[i])
    u = user_input.split()
    r = replaced.split()
    for j in range(len(u)):
        if u[j] == r[j]:
            replaced = replaced.replace(u[j],"^"+u[j]+"&")
    replaced = replaced.replace("a‍r", "%")
    return replaced


def uni2isi(user_input=None):
    replaced = user_input
    for i in range(len(unicode)):
        if unicode[i] in user_input:
            replaced = replaced.replace(unicode[i], legacy_isi[i])
    u = user_input.split()
    r = replaced.split()
    for j in range(len(u)):
        if u[j] == r[j]:
            replaced = replaced.replace(u[j],"("+u[j]+")")
    replaced = replaced.replace("Š‍y", "±")
    return replaced



from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="Uni-Legacy",
    version="1.0.0",
    author="Gavindu Tharaka",
    author_email="gavi.tharaka@gmail.com",
    description="A simple python library for convert sinhala unicode font to legacy font. Supported for FM fonts and Isi fonts.This library can be used offline",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="",
    packages=["uni_legacy"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6'
)
